Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: third_party/instrumented_libraries/download_build_install.py

Issue 361473002: Instrumented libraries: improve handling of custom patches. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: use -i to pass filename to patch Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/instrumented_libraries/freetype.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/instrumented_libraries/download_build_install.py
diff --git a/third_party/instrumented_libraries/download_build_install.py b/third_party/instrumented_libraries/download_build_install.py
index 1135ee33ad7c6258208438de368ab7f99f768807..ce31c4ab5b8f1dc330187b68c5115a72b807bc8e 100755
--- a/third_party/instrumented_libraries/download_build_install.py
+++ b/third_party/instrumented_libraries/download_build_install.py
@@ -286,6 +286,12 @@ def download_build_install(parsed_arguments):
'a package %s' % parsed_arguments.package))
with ScopedChangeDirectory(subdirectories[0]):
# Here we are in the package directory.
+ if parsed_arguments.patch:
+ shell_call(
+ 'patch -p1 -i %s/%s' %
+ (os.path.relpath(cd_package.old_path),
+ parsed_arguments.patch),
+ parsed_arguments.verbose)
if parsed_arguments.run_before_build:
shell_call(
'%s/%s' %
@@ -330,8 +336,9 @@ def main():
argument_parser.add_argument('--check-build-deps', action='store_true')
argument_parser.add_argument('--cc')
argument_parser.add_argument('--cxx')
- # This should be a shell script to run before building specific libraries
- # e.g. extracting archives with sources, patching makefiles, etc.
+ argument_parser.add_argument('--patch', default='')
+ # This should be a shell script to run before building specific libraries.
+ # This will be run after applying the patch above.
argument_parser.add_argument('--run-before-build', default='')
argument_parser.add_argument('--build-method', default='destdir')
argument_parser.add_argument('--sanitizer-blacklist', default='')
« no previous file with comments | « no previous file | third_party/instrumented_libraries/freetype.sh » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698